@@ -637,8 +637,12 @@ def load(lib, IM_VERSION):
         lib.MagickNormalizeImageChannel.restype = c_bool
     else:
         lib.MagickNormalizeImageChannel = None
-    lib.MagickOilPaintImage.argtypes = [c_void_p, c_double]
-    lib.MagickOilPaintImage.restype = c_bool
+    if is_im_6:
+        lib.MagickOilPaintImage.argtypes = [c_void_p, c_double]
+        lib.MagickOilPaintImage.restype = c_bool
+    else:
+        lib.MagickOilPaintImage.argtypes = [c_void_p, c_double, c_double]
+        lib.MagickOilPaintImage.restype = c_bool
     lib.MagickOpaquePaintImage.argtypes = [
         c_void_p, c_void_p, c_void_p, c_double, c_bool
     ]
@@ -668,8 +672,14 @@ def load(lib, IM_VERSION):
     lib.MagickPingImageBlob.restype = c_bool
     lib.MagickPingImageFile.argtypes = [c_void_p, c_void_p]
     lib.MagickPingImageFile.restype = c_bool
-    lib.MagickPolaroidImage.argtypes = [c_void_p, c_void_p, c_double]
-    lib.MagickPolaroidImage.restype = c_bool
+    if is_im_6:
+        lib.MagickPolaroidImage.argtypes = [c_void_p, c_void_p, c_double]
+        lib.MagickPolaroidImage.restype = c_bool
+    else:
+        lib.MagickPolaroidImage.argtypes = [
+            c_void_p, c_void_p, c_char_p, c_double, c_int
+        ]
+        lib.MagickPolaroidImage.restype = c_bool
     lib.MagickPosterizeImage.argtypes = [c_void_p, c_size_t, c_bool]
     lib.MagickPosterizeImage.restype = c_bool
     lib.MagickPreviewImages.argtypes = [c_void_p, c_int]
@@ -732,6 +742,7 @@ def load(lib, IM_VERSION):
             ]
             lib.MagickRotationalBlurImageChannel.restype = c_bool
     except AttributeError:
+        lib.MagickRotationalBlurImage = None
         pass
     lib.MagickSampleImage.argtypes = [c_void_p, c_size_t, c_size_t]
     lib.MagickSampleImage.restype = c_bool
@@ -919,10 +930,16 @@ def load(lib, IM_VERSION):
         lib.MagickSigmoidalContrastImageChannel.restype = c_bool
     else:
         lib.MagickSigmoidalContrastImageChannel = None
-    lib.MagickSimilarityImage.argtypes = [
-        c_void_p, c_void_p, c_void_p, c_double
-    ]
-    lib.MagickSimilarityImage.restype = c_void_p
+    if is_im_6:
+        lib.MagickSimilarityImage.argtypes = [
+            c_void_p, c_void_p, c_void_p, POINTER(c_double)
+        ]
+        lib.MagickSimilarityImage.restype = c_void_p
+    else:
+        lib.MagickSimilarityImage.argtypes = [
+            c_void_p, c_void_p, c_int, c_double, c_void_p, POINTER(c_double)
+        ]
+        lib.MagickSimilarityImage.restype = c_void_p
     lib.MagickSketchImage.argtypes = [c_void_p, c_double, c_double, c_double]
     lib.MagickSketchImage.restype = c_bool
     lib.MagickSmushImages.argtypes = [c_void_p, c_bool, c_ssize_t]
