@@ -34,7 +34,10 @@ def load(lib, IM_VERSION):
     .. versionadded:: 0.5.0
 
     """
+    lib.MagickDeleteImageArtifact.argtypes = [c_void_p, c_char_p]
+    lib.MagickDeleteImageArtifact.restype = c_int
     lib.MagickDeleteImageProperty.argtypes = [c_void_p, c_char_p]
+    lib.MagickDeleteImageProperty.restype = c_int
     lib.MagickDeleteOption.argtypes = [c_void_p, c_char_p]
     lib.MagickDeleteOption.restype = c_int
     lib.MagickGetAntialias.argtypes = [c_void_p]
@@ -69,6 +72,8 @@ def load(lib, IM_VERSION):
         c_void_p, c_char_p, POINTER(c_size_t)
     ]
     lib.MagickGetImageProperties.restype = POINTER(c_char_p)
+    lib.MagickGetInterlaceScheme.argtypes = [c_void_p]
+    lib.MagickGetInterlaceScheme.restype = c_int
     lib.MagickGetOption.argtypes = [c_void_p, c_char_p]
     lib.MagickGetOption.restype = c_char_p
     lib.MagickGetPointsize.argtypes = [c_void_p]
@@ -117,6 +122,8 @@ def load(lib, IM_VERSION):
     ]
     lib.MagickSetImageProfile.restype = c_int
     lib.MagickSetImageProperty.argtypes = [c_void_p, c_char_p, c_char_p]
+    lib.MagickSetInterlaceScheme.argtypes = [c_void_p, c_int]
+    lib.MagickSetInterlaceScheme.restype = c_int
     lib.MagickSetOption.argtypes = [c_void_p, c_char_p, c_char_p]
     lib.MagickSetOption.restype = c_int
     lib.MagickSetPointsize.argtypes = [c_void_p, c_double]
